async_state_view library

Widgets for rendering controller-owned asynchronous state.

Classes

AsyncData<T>
An asynchronous operation that completed with value.
AsyncError<T>
An asynchronous operation that failed with error and stackTrace.
AsyncLoading<T>
An asynchronous operation whose result is not yet available.
AsyncState<T>
The retained outcome of asynchronous work, independent of UI subscriptions.
AsyncStateBuilder<T>
Renders one branch of a retained AsyncState.

Typedefs

AsyncStateDataBuilder<T> = Widget Function(BuildContext context, T value)
Builds a widget for a successful asynchronous result.
AsyncStateErrorBuilder = Widget Function(BuildContext context, Object error, StackTrace stackTrace)
Builds a widget for a failed asynchronous result.